[supervisord]
nodaemon=true
logfile=/var/log/supervisor/supervisord.log
logfile_maxbytes=10MB

[program:odoo]
user=odoo
command=/home/odoo/instance/odoo/{{ odoo_binary }} -c /home/odoo/.openerp_serverrc
stdout_logfile=/var/log/supervisor/odoo_stdout.log
stderr_logfile=/var/log/supervisor/odoo_stdout.log
stdout_logfile_maxbytes=10MB
autostart=true
autorestart=true
exitcodes=0,2
startsecs=5
environment=HOME="/home/odoo",USER="odoo"
