{
    "0010_deactivate_parameters": "UPDATE ir_config_parameter SET value ='deployv_test' WHERE key ~* '[._-](api|token|key)|(api|token|key)[._-]';",
    "0020_partner": "UPDATE res_partner SET opt_out = True where opt_out is not True;",
    "0030_out_mail": "UPDATE ir_mail_server SET active = False, smtp_user = 'user', smtp_pass = 'pass';",
    "0040_in_mail": "UPDATE fetchmail_server SET active = False, \"user\" = 'user', password = 'pass';",
    "0050_old_pac": "UPDATE params_pac SET active = False;",
    "0060_pac": "UPDATE res_pac SET active = False;",
    "0070_cron": "UPDATE ir_cron SET active = False WHERE model <> 'osv_memory.autovacuum';",
    "0080_saas_cron": "UPDATE ir_cron SET active = False FROM ir_act_server WHERE ir_cron.cron_name = ir_act_server.name AND ir_act_server.model_name != 'ir.autovacuum';",
    "0090_notify": "UPDATE res_partner SET notify_email = 'none' where notify_email != 'none';",
    "0100_ir_action": "UPDATE base_action_rule SET active = False WHERE name LIKE '%Create Sale from Purchase%';",
    "0110_rules": "UPDATE base_action_rule SET active = False WHERE kind = 'on_time';",
    "0120_del_certificate": "DELETE FROM res_certificate;",
    "0130_orchest_settings": "UPDATE res_config_settings SET odoo_listener_id = '';",
    "0140_stored_passwords": "UPDATE network_software_logpass SET password = '123456';",
    "0150_rabbit_active": "UPDATE network_service SET active = False, host = '0.0.0.0', virtual_host = 'vhost';",
    "0160_instance_ssh": "update deploy_group set ssh_file = null;",
    "0170_google_analytics": "UPDATE website SET google_analytics_key = '';",
    "0180_payment_acquirer": "UPDATE payment_acquirer SET environment='test';",
    "0185_payment_acquirer_v14": "UPDATE payment_acquirer SET state='test' WHERE state='enabled';",
    "0190_hotjar": "UPDATE ir_ui_view SET active=false WHERE key like '%.hotjar%';",
    "0200_l10n_pe_sunat": "UPDATE res_company SET l10n_pe_edi_sunat_username = 'MODDATOS', l10n_pe_edi_sunat_password = 'MODDATOS', l10n_pe_edi_sunat_url = 'https://e-beta.sunat.gob.pe/ol-ti-itcpfegem-beta/billService?wsdl';",
    "0210_s3_config": "UPDATE s3_config_settings SET s3_bucket='', s3_secret_key='', s3_access_key_id='';",
    "0220_l10n_mx_edi_company": "UPDATE res_company SET l10n_mx_edi_pac_username='', l10n_mx_edi_pac_password='', l10n_mx_edi_pac_test_env = true;",
    "0230_rfc_res_partner_mx": "UPDATE res_partner AS partner SET vat = 'EKU9003173C9' FROM res_company AS company, res_country AS country WHERE company.partner_id = partner.id AND partner.country_id = country.id AND country.code = 'MX';",
    "0240_orchest_parameters": "UPDATE ir_config_parameter SET value= '' WHERE key = 'orchestv.odoo_listener_id';",
    {%- if use_mailhog -%}
    "0250_out_mail": "UPDATE ir_mail_server SET active = true, smtp_host = '1.1.1.1', smtp_encryption = 'none', smtp_port = 25, smtp_user = 'user', smtp_pass = 'pass';",
    "0260_mail_cron": "UPDATE ir_cron set active = true where id in (select res_id from ir_model_data where module = 'mail' and name = 'ir_cron_mail_scheduler_action');",
    {%- endif %}
    {%- if not migration -%}
    "0270_db_uuid": "UPDATE ir_config_parameter SET value = '{{ uuid }}' WHERE key = 'database.uuid';",
    "0275_multi_company_db_uuid": "UPDATE ir_property SET value_text = '{{ uid }}' WHERE fields_id = {{ field_id }} and name ilike '%database.uuid%';",
    {%- endif %}
    "0280_multi_company_s3_irconfig": "UPDATE ir_property SET value_text = '' WHERE fields_id = {{ field_id }} and name similar to '%(s3.access_key_id|s3.bucket|s3.secret_key)%';",
    "0290_s3_irconfig": "UPDATE ir_config_parameter SET value = '' WHERE key = 's3.bucket';",
    "0300_multi_company_orchest_parameters": "UPDATE ir_property SET value_text='' WHERE fields_id = {{ field_id }} and name similar to '%(orchestv.github_access_token|orchestv.docker_hub_access_token|orchestv.quay_io_access_token|orchestv.odoo_listener_id|orchestv.worker_security_token|orchestv.gitlab_access_token)%';",
    {%- if nginx_url -%}
    "0310_multi_company_url_freeze": "UPDATE ir_property set value_text = '{{ nginx_url }}' where name ilike '%web.base.url.freeze%' and fields_id = {{ field_id }};",
    "0320_url_freeze": "UPDATE ir_config_parameter SET value='{{ nginx_url }}' WHERE key='web.base.url.freeze';",
    "0330_multi_company_web_base_url": "UPDATE ir_property set value_text = '{{ nginx_url }}' where name ilike '%web.base.url%' and fields_id = {{ field_id }};",
    "0340_web_base_url": "UPDATE ir_config_parameter SET value='{{ nginx_url }}' WHERE key='web.base.url';",
    {%- endif %}
    {%- if not nginx_url -%}
    "0350_multi_company_url_freeze": "UPDATE ir_property set value_text = '' WHERE name ilike '%web.base.url.freeze%' and fields_id = {{ field_id }};",
    "0360_multi_company_web_base_url": "UPDATE ir_property SET value_text = '' WHERE name ilike '%web.base.url%' and fields_id = {{ field_id }};",
    "0370_url_freeze": "DELETE FROM ir_config_parameter WHERE key = 'web.base.url.freeze';",
    "0380_web_base_url": "INSERT INTO ir_config_parameter(key, value) VALUES('web.base.url', 'http://localhost:8069') ON CONFLICT(key) DO UPDATE SET value = 'http://localhost:8069';",
    {%- endif %}
    "0400_deleted_xsd": "DELETE FROM ir_attachment where name ilike '%xsd%' AND res_model IS NULL AND res_field IS NULL;",
    "0410_act_server": "UPDATE ir_act_server SET binding_model_id=(select id from ir_model where model = 'res.company'), binding_type='action' where id in (select res_id from ir_model_data where name='l10n_mx_edi_xsd_server_action');",
    "0420_deleted_xml_xsd": "DELETE FROM ir_model_data where module = 'l10n_mx_edi' and name ilike '%_xsd' or name ilike 'xsd_%';",
    "0430_xunnel_test": "UPDATE res_company SET xunnel_api_key='5e520769413a2bc95e337ad6ee25e70d' WHERE id=1;",
    "0440_xunnel_paybook": "UPDATE ir_config_parameter SET value = '9e9cefcd65b1b9181045dccd8b7e5b8d' WHERE key='xunnel_admin.paybook_api_key';",
    "0450_orchestv_minimum_github_api": "UPDATE ir_config_parameter SET value = '1000' WHERE key='orchestv.minimum_github_api_limit';",
    "0460_xunnel_test_env": "UPDATE res_company SET xunnel_testing = 't';",
    "0470_xunnel_token": "UPDATE res_config_settings SET xunnel_token = ''",
    "0480_set_xunnel_token": "update res_company set xunnel_token='ba45bf4ed4f94e18ad023936982a92cd';",
    "0490_galaxy_environment": "UPDATE ir_config_parameter SET value='test' WHERE key='galaxy.environment';",
    "0500_galaxy_uuid": "UPDATE ir_config_parameter SET value='' WHERE key='galaxy.push_uuid';",
    "0510_absa_importer": "UPDATE absa_importer SET active='False' WHERE end_point LIKE '%push%';",
    "0520_galaxy_url": "UPDATE ir_config_parameter SET value='https://legacytest.grupoabsa.com' WHERE key='galaxy.url';",
    "0530_absa_importer_url": "UPDATE absa_importer SET end_point = REPLACE(end_point, 'legacy.', 'legacytest.');",
    "0531_absa_importer_url_csv": "UPDATE absa_importer_csv SET end_point = REPLACE(end_point, 'legacy.', 'legacytest.');",
    "0540_delivery_bf": "UPDATE delivery_carrier SET prod_environment = False, easypost_production_api_key = 'easypost_test_api_key';",
    "0550_conecta_keys": "update payment_acquirer set conekta_private_key='Dummy', conekta_public_key='Dummy';",
    "0560_l10n_pe_edi_del_certificate": "DELETE FROM l10n_pe_edi_certificate;",
    "0570_l10n_pe_edi_l10n_pe_sunat_legacy": "UPDATE res_company SET l10n_pe_edi_ose_username = '', l10n_pe_edi_ose_password = '', l10n_pe_edi_environment = true;",
    "0575_l10n_pe_edi_l10n_pe_sunat": "UPDATE res_company SET l10n_pe_edi_provider_username = '', l10n_pe_edi_provider_password = '', l10n_pe_edi_test_env = true;",
    "0580_cr_edi_l10n": "UPDATE res_company SET l10n_cr_edi_client_api_key = '', l10n_cr_edi_test_env = true;",
    "0590_facebook_pixel": "UPDATE website SET facebook_pixel_code='';",
    "0600_gtm": "UPDATE website SET google_tag_manager_key=''",
    "0610_sms_gateaway": "UPDATE gateway_setup SET gateway_url='';",
    "0620_set_payment_acquirer_authorize_param": "UPDATE payment_acquirer SET authorize_login='dummy', authorize_transaction_key='dummy' WHERE provider='authorize';",
    "0625_set_payment_acquirer_authorize_v14": "UPDATE payment_acquirer SET authorize_signature_key='dummy', authorize_client_key='dummy' WHERE provider='authorize';",
    "0630_set_payment_acquirer_bambora_param": "UPDATE payment_acquirer SET bambora_login='dummy', bambora_transaction_key='dummy', bambora_report_key='dummy', bambora_batch_process_key='dummy' WHERE provider='bambora';",
    "0631_payment_acquirer_alipay": "UPDATE payment_acquirer SET alipay_merchant_partner_id='dummy', alipay_md5_signature_key='dummy', alipay_seller_email='dummy' WHERE provider='alipay';",
    "0632_payment_acquirer_paypal": "UPDATE payment_acquirer SET paypal_email_account='dummy', paypal_seller_account='dummy', paypal_pdt_token='dummy' WHERE provider='paypal';",
    "0640_set_validation_email_inactive": "UPDATE res_company SET sendgrid_validation_email=False;UPDATE res_company SET sendgrid_email_api_key='dummy', sendgrid_test_environment=True, password_expiration=0;",
    "0650_set_random_payment_token_ref": "UPDATE payment_token SET acquirer_ref='dummy';",
    "0652_set_random_payment_token_auth": "UPDATE payment_token SET authorize_profile=Null;",
    "0654_set_random_payment_token_cyber": "UPDATE payment_token SET cybersource_profile=Null;",
    "0655_set_random_payment_token_bambora": "UPDATE payment_token SET bambora_profile=Null;",
    "0660_set_validation_email_inactive": "UPDATE res_company SET sendgrid_validation_email=False;UPDATE res_company SET sendgrid_email_api_key='dummy';",
    "0680_deactivate_cdn": "UPDATE website SET cdn_activated=False, cdn_url='KeyCDN';",
    "0690_delete_pass_history": "DELETE FROM res_users_pass_history;",
    "0700_set_queue_jobs_done": "UPDATE queue_job SET state = 'failed' WHERE state IN ('pending', 'started', 'enqueued');",
    "0710_set_subscription_close": "UPDATE sale_subscription SET stage_id=(SELECT id FROM sale_subscription_stage WHERE category='closed' LIMIT 1) WHERE stage_category='progress';UPDATE sale_subscription SET stage_category='closed' WHERE stage_category='progress';UPDATE sale_subscription SET to_renew = False WHERE to_renew = True;",
    "0720_set_payment_acquirer_cybersource": "UPDATE payment_acquirer SET cybersource_login='dummy', cybersource_transaction_key='dummy', cybersource_signature_secret='dummy', cybersource_profile_id='dummy' WHERE provider='cybersource';",
    "0730_api_gt": "DELETE FROM api_data_configuration;",
    "0740_delete_cache_html": "DELETE FROM ir_ui_view_cache;",
    "0750_rm_saml_cert": "DELETE FROM ir_attachment WHERE res_model = 'auth.saml.provider' AND res_field = 'sp_pem';",
    "0760_disable_saml_providers": "UPDATE auth_saml_provider SET active = FALSE WHERE active IS TRUE;",
    "0770_cgp_pin_hostid": "UPDATE ir_config_parameter SET value = 'Vne2qE9Aw2i2gXLgB89+A3NG+aiKSiN8ZyTU7J28nKnL3fd2wyZbAlMGYYpSL/sWPLUS4ziG9N+A0tr46fTSgg==' WHERE key = 'SINPE.CGP_PIN_HOSTID';",
    "0780_sinpe_environment": "UPDATE ir_config_parameter SET value = 'test' WHERE key = 'SINPE.ENVIRONMENT';",
    "0790_sap_user": "UPDATE ir_config_parameter SET value = '' WHERE key = 'sbd.sap.user';",
    "0800_sap_password": "UPDATE ir_config_parameter SET value = '' WHERE key = 'sbd.sap.password';",
    "0810_sap_base_url": "UPDATE ir_config_parameter SET value = '' WHERE key = 'sbd.sap.base.url';",
    "0820_sap_client": "UPDATE ir_config_parameter SET value = '' WHERE key = 'sbd.sap.client';",
    "0830_set_payment_acquirer_bambora": "UPDATE payment_acquirer SET bamboraeft_merchant_id='dummy', bamboraeft_batch_api='dummy', bamboraeft_report_api= 'dummy', bamboraeft_payment_api='dummy', bamboraeft_profile_api='dummy' WHERE provider='bamboraeft';",
    "0840_website_robots": "UPDATE website SET robots_txt = 'Disallow: /';",
    "0915_assa_abloy_callback_cards": "UPDATE ir_config_parameter SET value='0' WHERE key='assa_abloy.callback_cards'",
    "0920_rmscloud_use_training_database": "UPDATE ir_config_parameter SET value=true WHERE key='rmscloud.use_training_database'",
    "0925_rmscloud_avoid_push_transactions": "UPDATE ir_config_parameter SET value=true WHERE key='rmscloud.avoid_push_transactions'",
    "0930_rmscloud_client_id": "UPDATE ir_config_parameter SET value='0' WHERE key='rmscloud.client_id'",
    "0935_rmscloud_client_password": "UPDATE ir_config_parameter SET value='0' WHERE key='rmscloud.client_password'",
    "0940_rmscloud_agent_password": "UPDATE ir_config_parameter SET value='0' WHERE key='rmscloud.agent_password'",
    "0945_rmscloud_agent_id": "UPDATE ir_config_parameter SET value='0' WHERE key='rmscloud.agent_id'",
    "0950_rmscloud_url": "UPDATE ir_config_parameter SET value='https://betarestapi10.rmscloud.com' WHERE key='rmscloud.url'",
    "0955_rmscloud_token": "UPDATE ir_config_parameter SET value='0' WHERE key='rmscloud.token'",
    "0960_pos_villa_avoid_push_sales": "UPDATE ir_config_parameter SET value=true WHERE key='pos_villa.avoid_push_sales'",
    "0965_pos_villa_user": "UPDATE ir_config_parameter SET value='OdooTest' WHERE key='pos_villa.user'",
    "0970_pos_villa_user_password": "UPDATE ir_config_parameter SET value='0' WHERE key='pos_villa.password'",
    "0975_pos_villa_url": "UPDATE ir_config_parameter SET value='https://restful.frontoffice.villagroup.com/PMSBusinessServerTest/BusinessServersISAPI.dll' WHERE key='pos_villa.url'"

}
