[program:sshd]
user=root
command=/usr/sbin/sshd -D -e
stderr_logfile=/var/log/supervisor/sshd.log
stdout_logfile=/var/log/supervisor/sshd.log
autostart=true
autorestart=unexpected
exitcodes=0,2
startsecs=2
