[program:postgresql]
user=postgres
command=/usr/lib/postgresql/{{ psql_version }}/bin/postgres -D /var/lib/postgresql/{{ psql_version }}/main -c config_file=/etc/postgresql/{{ psql_version }}/main/postgresql.conf
stderr_logfile=/var/log/supervisor/postgres_stderr.log
stdout_logfile=/var/log/supervisor/postgres_stdout.log
autorestart=unexpected
exitcodes=0,2
startsecs=10
autostart=false
